==> haskell-jose-0.6.0.3-23-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-jose.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: jose
version: 0.6.0.3
id: jose-0.6.0.3-3Hnxnd9l9hRC5A43kT8SuA
key: jose-0.6.0.3-3Hnxnd9l9hRC5A43kT8SuA
license: Apache-2.0
copyright: Copyright (C) 2013, 2014, 2015, 2016, 2017  Fraser Tweedale
maintainer: frase@frase.id.au
homepage: https://github.com/frasertweedale/hs-jose
synopsis: Javascript Object Signing and Encryption and JSON Web Token library
description:
    .
    An implementation of the Javascript Object Signing and Encryption
    (JOSE) and JSON Web Token (JWT; RFC 7519) formats.
    .
    The JSON Web Signature (JWS; RFC 7515) implementation is complete.
    .
    EdDSA signatures (RFC 8037) are supported (Ed25519 only).
    .
    JWK Thumbprint (RFC 7638) is supported (requires /aeson/ >= 0.10).
    .
    JSON Web Encryption (JWE; RFC 7516) is not yet implemented.
    .
    The __ECDSA implementation is vulnerable to timing attacks__ and
    should only be used for verification.
category: Cryptography
author: Fraser Tweedale
exposed: True
indefinite: False
exposed-modules:
    Crypto.JOSE Crypto.JOSE.AESKW Crypto.JOSE.Compact Crypto.JOSE.Error
    Crypto.JOSE.Header Crypto.JOSE.JWA.JWE Crypto.JOSE.JWA.JWE.Alg
    Crypto.JOSE.JWA.JWK Crypto.JOSE.JWA.JWS Crypto.JOSE.JWE
    Crypto.JOSE.JWK Crypto.JOSE.JWK.Store Crypto.JOSE.JWS
    Crypto.JOSE.Types Crypto.JWT
hidden-modules: Crypto.JOSE.TH Crypto.JOSE.Types.Internal
                Crypto.JOSE.Types.Orphans
abi: 6ea93a5a00a3f7d9ad490e212dd25849
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/jose-0.6.0.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/jose-0.6.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/jose-0.6.0.3
hs-libraries: HSjose-0.6.0.3-3Hnxnd9l9hRC5A43kT8SuA
depends:
    base-4.10.1.0 attoparsec-0.13.2.2-1IsPw46SBaXMxKqrmF8MV
    base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be
    concise-0.1.0.0-H18Pz7hHb17CN7KETxpqwt containers-0.5.10.2
    cryptonite-0.24-6O2YBbNLStYJmwkq5zLEJx
    lens-4.15.4-8VElApQlNdSC7zfU0AKr8J
    memory-0.14.14-FiOA0zEQIqU9pMZGNyv72b
    monad-time-0.2-LUGpLHgSHKFHCiGjsIZzVq
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q template-haskell-2.12.0.0
    safe-0.3.15-EroU33EYnr02fGSZYGiX97
    aeson-1.2.3.0-FF3lFd58LTtGOe8yOI27Zo
    unordered-containers-0.2.8.0-YOGDwOwys3HjU5i3g27KB
    bytestring-0.10.8.2 text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    time-1.8.0.2 network-uri-2.6.1.0-BbYfQUrqmQG8TYLVq3Shq8
    QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9
    quickcheck-instances-0.3.16.1-F3CGOCfWzAIE2k3RoBmtPK
    x509-1.7.2-EVk4f2BV7NpJF8rKRYOGbC
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             attoparsec-0.13.2.2-1IsPw46SBaXMxKqrmF8MV=c494333baf54c0b8596ba018ce99c526
             base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be=fd5db0dc9688093c1ac2c3223371478e
             concise-0.1.0.0-H18Pz7hHb17CN7KETxpqwt=2bc573d5e295ae237440b6f2a893f53d
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             cryptonite-0.24-6O2YBbNLStYJmwkq5zLEJx=f485729293cc44bcb426ebfe7176782a
             lens-4.15.4-8VElApQlNdSC7zfU0AKr8J=3fc6957787002c0dde8bc9e06a51d485
             memory-0.14.14-FiOA0zEQIqU9pMZGNyv72b=31288e97a1618db31ba2d3698d738018
             monad-time-0.2-LUGpLHgSHKFHCiGjsIZzVq=116f431f7921957b9b3eca4c6ee81af5
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=0f8a4b2bc8ee8ce3a5dab66f0eb14e7c
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
             safe-0.3.15-EroU33EYnr02fGSZYGiX97=604c7b7c109a34b58d71795df287548a
             aeson-1.2.3.0-FF3lFd58LTtGOe8yOI27Zo=6be681d1d865a75a35865349e66ae8da
             unordered-containers-0.2.8.0-YOGDwOwys3HjU5i3g27KB=1ae4406c8abf6f6a305796d42b6e1b7b
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             network-uri-2.6.1.0-BbYfQUrqmQG8TYLVq3Shq8=ab32d4d3146164271ec97b5409cdba0c
             QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9=77baeaa97e72dac9529ccf150f178180
             quickcheck-instances-0.3.16.1-F3CGOCfWzAIE2k3RoBmtPK=35e49374d54b7b02971284fae4a60a2d
             x509-1.7.2-EVk4f2BV7NpJF8rKRYOGbC=8743d5f25d2aa44c9bee266dde37dce6
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
haddock-interfaces: /usr/share/doc/haskell-jose/html/jose.haddock
haddock-html: /usr/share/doc/haskell-jose/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-jose-0.6.0.3-24-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-jose.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: jose
version: 0.6.0.3
id: jose-0.6.0.3-1ajJMY5o5um5lHKyIW2W9
key: jose-0.6.0.3-1ajJMY5o5um5lHKyIW2W9
license: Apache-2.0
copyright: Copyright (C) 2013, 2014, 2015, 2016, 2017  Fraser Tweedale
maintainer: frase@frase.id.au
homepage: https://github.com/frasertweedale/hs-jose
synopsis: Javascript Object Signing and Encryption and JSON Web Token library
description:
    .
    An implementation of the Javascript Object Signing and Encryption
    (JOSE) and JSON Web Token (JWT; RFC 7519) formats.
    .
    The JSON Web Signature (JWS; RFC 7515) implementation is complete.
    .
    EdDSA signatures (RFC 8037) are supported (Ed25519 only).
    .
    JWK Thumbprint (RFC 7638) is supported (requires /aeson/ >= 0.10).
    .
    JSON Web Encryption (JWE; RFC 7516) is not yet implemented.
    .
    The __ECDSA implementation is vulnerable to timing attacks__ and
    should only be used for verification.
category: Cryptography
author: Fraser Tweedale
exposed: True
indefinite: False
exposed-modules:
    Crypto.JOSE Crypto.JOSE.AESKW Crypto.JOSE.Compact Crypto.JOSE.Error
    Crypto.JOSE.Header Crypto.JOSE.JWA.JWE Crypto.JOSE.JWA.JWE.Alg
    Crypto.JOSE.JWA.JWK Crypto.JOSE.JWA.JWS Crypto.JOSE.JWE
    Crypto.JOSE.JWK Crypto.JOSE.JWK.Store Crypto.JOSE.JWS
    Crypto.JOSE.Types Crypto.JWT
hidden-modules: Crypto.JOSE.TH Crypto.JOSE.Types.Internal
                Crypto.JOSE.Types.Orphans
abi: 92e08e49dec634a847aedd6e7860334d
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/jose-0.6.0.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/jose-0.6.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/jose-0.6.0.3
hs-libraries: HSjose-0.6.0.3-1ajJMY5o5um5lHKyIW2W9
depends:
    base-4.10.1.0 attoparsec-0.13.2.2-1IsPw46SBaXMxKqrmF8MV
    base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be
    concise-0.1.0.0-8h517MvblvH6I4FrbAVal5 containers-0.5.10.2
    cryptonite-0.24-6O2YBbNLStYJmwkq5zLEJx
    lens-4.15.4-GHG2RfIFmRNGem6EMVKVve
    memory-0.14.14-FiOA0zEQIqU9pMZGNyv72b
    monad-time-0.2-LUGpLHgSHKFHCiGjsIZzVq
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q template-haskell-2.12.0.0
    safe-0.3.15-EroU33EYnr02fGSZYGiX97
    aeson-1.2.3.0-FF3lFd58LTtGOe8yOI27Zo
    unordered-containers-0.2.8.0-YOGDwOwys3HjU5i3g27KB
    bytestring-0.10.8.2 text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    time-1.8.0.2 network-uri-2.6.1.0-BbYfQUrqmQG8TYLVq3Shq8
    QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9
    quickcheck-instances-0.3.16.1-F3CGOCfWzAIE2k3RoBmtPK
    x509-1.7.2-EVk4f2BV7NpJF8rKRYOGbC
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             attoparsec-0.13.2.2-1IsPw46SBaXMxKqrmF8MV=c494333baf54c0b8596ba018ce99c526
             base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be=fd5db0dc9688093c1ac2c3223371478e
             concise-0.1.0.0-8h517MvblvH6I4FrbAVal5=a25c4b927eda8b108c6256ba3a3f9082
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             cryptonite-0.24-6O2YBbNLStYJmwkq5zLEJx=f485729293cc44bcb426ebfe7176782a
             lens-4.15.4-GHG2RfIFmRNGem6EMVKVve=8c5896db7f5dc309286e0cf159a81474
             memory-0.14.14-FiOA0zEQIqU9pMZGNyv72b=31288e97a1618db31ba2d3698d738018
             monad-time-0.2-LUGpLHgSHKFHCiGjsIZzVq=116f431f7921957b9b3eca4c6ee81af5
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=0f8a4b2bc8ee8ce3a5dab66f0eb14e7c
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
             safe-0.3.15-EroU33EYnr02fGSZYGiX97=604c7b7c109a34b58d71795df287548a
             aeson-1.2.3.0-FF3lFd58LTtGOe8yOI27Zo=6be681d1d865a75a35865349e66ae8da
             unordered-containers-0.2.8.0-YOGDwOwys3HjU5i3g27KB=1ae4406c8abf6f6a305796d42b6e1b7b
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             network-uri-2.6.1.0-BbYfQUrqmQG8TYLVq3Shq8=ab32d4d3146164271ec97b5409cdba0c
             QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9=77baeaa97e72dac9529ccf150f178180
             quickcheck-instances-0.3.16.1-F3CGOCfWzAIE2k3RoBmtPK=35e49374d54b7b02971284fae4a60a2d
             x509-1.7.2-EVk4f2BV7NpJF8rKRYOGbC=8743d5f25d2aa44c9bee266dde37dce6
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
haddock-interfaces: /usr/share/doc/haskell-jose/html/jose.haddock
haddock-html: /usr/share/doc/haskell-jose/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
